@@ -8,7 +8,7 @@ use ExtUtils::MakeMaker;
 use XS::Install::Util;
 use XS::Install::Payload;
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.2.1';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile not_available/;
@@ -286,7 +286,7 @@ sub process_module_binary {
     
     process_binary($params);
     
-    _string_merge($params->{XSOPT}, '-C++ -csuffix .cc') if $params->{CPLUS};
+    _string_merge($params->{XSOPT}, '-C++') if $params->{CPLUS};
     
     $params->{clean}{FILES} .= ' $(O_FILES)';
     
@@ -302,14 +302,18 @@ sub process_binary {
         canonize_array_files($params->{XS});
         $params->{XS} = { map {$_ => undef} @{$params->{XS}} };
     }
+
     foreach my $xsfile (keys %{$params->{XS}}, map { _scan_files($xs_mask, $_) } @{$params->{SRC}}) {
         next if $params->{XS}{$xsfile};
         my $cfile = $xsfile;
         $cfile =~ s/\.xs$/.xs.$cext/ or next;
         $params->{XS}{$xsfile} = $cfile;
-        
+
+        my $suffix = $cfile;
+        $suffix =~ s/^[^.]+//;
+
         push @{$params->{postamble}}, "$cfile : $xsfile \$(FIRST_MAKEFILE)\n".
-            "\t\$(XSUBPPRUN) \$(XSPROTOARG) \$(XSUBPPARGS) \$(XSUBPP_EXTRA_ARGS) $xsfile > ${xsfile}c\n".
+            "\t\$(XSUBPPRUN) \$(XSPROTOARG) \$(XSUBPPARGS) -csuffix $suffix \$(XSUBPP_EXTRA_ARGS) $xsfile > ${xsfile}c\n".
             "\t\$(MV) ${xsfile}c $cfile";
     }
 
